import { BrowserWaits } from 'gtaa-interface-ts/wait/browser-waits.interface';
export declare class BrowserWait implements BrowserWaits {
    /**
     * Generic method to wait for an element to exist in SUT.
     * @param locator Element locator as string, could be a css locator.
     * @param timeout Timeout to wait for element to be present in SUT, default being 1 minute.
    */
    untilElementExists(locator: string, timeout?: number): Promise<void>;
    /**
     * Generic method to wait for an element to be visible in SUT.
     * @param locator Element locator as string, could be a css locator.
     * @param timeout Timeout to wait for element to be visible, default being 1 minute.
    */
    untilElementIsVisible(locator: string, timeout?: number): Promise<void>;
    /**
     *
    */
    forElementToBeVisible(locator: string, timeout: number): Promise<boolean>;
    /**
     * Generic method to wait until a given element is no longer visible on the screen.
     * @param locator Element locator as string, could be a css locator.
     * @param timeout The timeout in seconds until the wait fails.
    */
    untilElementIsInvisible(locator: string, timeout?: number): Promise<void>;
    /**
     * Generic method to wait for an element to be clickable in SUT.
     * @param locator Element locator as string, could be a css locator.
     * @param timeout Timeout to wait for element to be clickable, default being 1 minute.
    */
    untilElementIsClickable(locator: string, timeout?: number): Promise<void>;
    /**
     * Wait until a certain number of elements appear on screen.
     * @param locator Element locator as string, could be a css locator.
    */
    elementCount(locator: string, count: number, timeout?: number): Promise<void>;
    /**
     * Wait until browser starts loading and then stop loading.
    */
    untilLoaded(timeout?: number): Promise<void>;
}
